#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : DeepTricks.
# @File         : CalibratedClassifierCV
# @Time         : 2019-10-09 18:10
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


"""概率校准"""

from sklearn.calibration import CalibratedClassifierCV



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : Python.
# @File         : wandb_callback
# @Time         : 2020-03-13 12:48
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : https://github.com/wandb/client


